#!/bin/sh

############################################################################
#
#  Source Name : set_proxy.sh
#  Result Code : 0 -> No errors occurred. Proxy.xml was copied.
#                1 -> No errors occurred. Proxy.xml was created.
#                3 -> No errors occurred. Proxy.xml was not created because already installed.
#
############################################################################

PROXY_FILE_NAME='Proxy.xml'
OUT_FILE_DIR='/var/opt/EIZO/ColorNavigator NetAgent/'

IN_FILE="./${PROXY_FILE_NAME}"
OUT_FILE="${OUT_FILE_DIR}${PROXY_FILE_NAME}"

# Create NetAgent directory
if [ ! -d "${OUT_FILE_DIR}" ]; then
    mkdir -p "${OUT_FILE_DIR}"
    chmod 777 -R "${OUT_FILE_DIR}"
fi

# Copy proxy.xml if exists
if [ -e "${IN_FILE}" ]; then
    cp -p "${IN_FILE}" "${OUT_FILE}"
    chmod 666 "${OUT_FILE}"
    exit 0
fi

# Do nothing if already installed
if [ -e "${OUT_FILE}" ]; then
    exit 3
fi

# Create proxy.xml if not exists

# - Get from environment variables
PROXY_VALUE=
PORT_VALUE=
HTTPS_NM=HTTPS_
for i in `env | grep -i ${HTTPS_NM} | sort -u | cut -d= -f2 | sed -e "s/[^\/]*:\/\///"`
do
    if [ ! -e $i ]; then
        PROXY_VALUE=`echo $i | cut -d: -f1`
        PORT_VALUE=`echo $i | cut -s -d: -f2`
        break
    fi
done
if [ ! -e ${PORT_VALUE} ] && [ ${PORT_VALUE} = 0 ] ; then
    PORT_VALUE=
else
    PORT_VALUE=${PORT_VALUE//[!0-9]/}
fi

# - Create
echo "<?xml version=\"1.0\" encoding=\"UTF-8\"?>" > "${OUT_FILE}"
echo "<Proxy Version=\"1\">" >> "${OUT_FILE}"
if [ -e ${PROXY_VALUE} ]; then
    echo "  <Host/>" >> "${OUT_FILE}"
else
    echo "  <Host>${PROXY_VALUE}</Host>" >> "${OUT_FILE}"
fi
if [ -e ${PORT_VALUE} ]; then
    echo "  <Port/>" >> "${OUT_FILE}"
else
    echo "  <Port>${PORT_VALUE}</Port>" >> "${OUT_FILE}"
fi
echo "</Proxy>" >> "${OUT_FILE}"
chmod 666 "${OUT_FILE}"

exit 1
