#!/bin/sh

############################################################################
#
#  Source Name : install.sh
#  Option      : No option.
#  Result Code : 0    -> No errors occurred.
#              : 1    -> No errors occurred. Connection.xml not found. 
#                        And continue installation.
#              : 130  -> Connection.xml not found.
#                        And Did not continue installation.
#              : 131  -> Did not agree to a license.
#              : 132  -> Failed su or install_su_parent.sh.
#              : 133  -> CN7 is installed.
#
############################################################################

NO_ERR_RET=0

if test -e "/opt/EIZO/ColorNavigator 7/ColorNavigator 7"
then
	echo "ColorNavigator NetAgent cannot be installed with ColorNavigator 7. Uninstall ColorNavigator 7 and perform the installation again."
	exit 133
fi

#
cd `dirname $0`

# check Connection.xml
if ! test -e Connection.xml; then
	echo "Connection.xml was not found."
	echo -n "Do you continue?[Y/n] : "
	while read ch
	do
		ch=`echo ${ch} | tr "[A-Z]" "[a-z]"`
		
		if [ "${ch}" = "y" -o "${ch}" = "yes" ]; then
			echo "Continue installation."
			NO_ERR_RET=1
			break
		elif [ "${ch}" = "n" -o "${ch}" = "no" ]; then
			echo "Cancel."
			exit 130
		fi
	done
fi

# check license
echo "To continue installing the software you must agree to the terms of the software license agreement(eula/EULA)."
echo -n "Do you agree?[Y/n] : "

#
while read ch
do
	#
	ch=`echo ${ch} | tr "[A-Z]" "[a-z]"`
	
	#
	if [ "${ch}" = "y" -o "${ch}" = "yes" ]; then
		# install by root user
		if [ "`whoami`" != "root" ]; then
			echo "Please enter root password."
		fi
		# failed su: return-value is 125.
		# failed install_su_parent.sh: return-value is 128 and over.
		# -> 125 and over is error.
		if su -c "./bin/install_su_parent.sh" ; test  $? -lt 125 ; then
			echo "Done."
		else
			echo "Failed."
			exit 132
		fi
		
		break;
	elif [ "${ch}" = "n" -o "${ch}" = "no" ]; then
		echo "Cancel."
		exit 131
	fi
done

exit ${NO_ERR_RET}
